/// Contains configuration value for the app.
///
/// Every pieces of the app that is related to a brand should be included in
/// a environment variable. The app needs to be as generic as possible.
/// {@category Entities}

library environment;

import 'dart:convert';

import 'package:built_value/built_value.dart';
import 'package:built_value/serializer.dart';
import 'package:puma_core/serializers.dart';

part 'environment.g.dart';

abstract class Environment implements Built<Environment, EnvironmentBuilder> {
  Environment._();

  factory Environment([updates(EnvironmentBuilder b)]) = _$Environment;

  @BuiltValueField(wireName: 'appTitle')
  String? get appTitle;

  @BuiltValueField(wireName: 'environment')
  String? get environment;

  @BuiltValueField(wireName: 'defaultOrganizationToken')
  String? get defaultOrganizationToken;

  @BuiltValueField(wireName: 'websocketEndpoint')
  String? get websocketEndpoint;

  @BuiltValueField(wireName: 'websocketToken')
  String? get websocketToken;

  @BuiltValueField(wireName: 'themePrimarySwatch')
  String? get themePrimarySwatch;

  @BuiltValueField(wireName: 'initializeMainState')
  bool? get initializeMainState;

  @BuiltValueField(wireName: 'forceLocal')
  String? get forceLocal;

  @BuiltValueField(wireName: 'appStoreSandbox')
  bool? get appStoreSandbox;

  @BuiltValueField(wireName: 'appleAppStorePassword')
  String? get appleAppStorePassword;

  @BuiltValueField(wireName: 'apiEndpoint')
  String? get apiEndpoint;
  // Example: api.wa.alpha.wa-labs.com/v3

  String toJson() {
    return json.encode(serializers.serializeWith(Environment.serializer, this));
  }

  static Environment? fromJson(String jsonString) {
    return serializers.deserializeWith(
        Environment.serializer, json.decode(jsonString));
  }

  static Serializer<Environment> get serializer => _$environmentSerializer;
}
